<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es-ES" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="85"/>
      <source>Select</source>
      <translation>Seleccionar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="86"/>
      <source>Zoom</source>
      <translation>Aumentar/Disminuir</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="87"/>
      <source>Rotate</source>
      <translation>Rotar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="88"/>
      <source>Pan</source>
      <translation>Panear</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="89"/>
      <source>Tilt</source>
      <translation>Inclinación</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="90"/>
      <source>Navigation style</source>
      <translation>Estilo de navegación</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="91"/>
      <source>Page Up or Page Down key.</source>
      <translation>Tecla Page Up o Page Down.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="92"/>
      <source>Rotation focus</source>
      <translation>Foco de rotación</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="93"/>
      <source>Middle mouse button or H key.</source>
      <translation>Botón central del ratón o la tecla H.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="95"/>
      <source>Middle mouse button.</source>
      <translation>Botón central del ratón.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="98"/>
      <source>Navigation style not recognized.</source>
      <translation>Estilo de navegación no reconocido.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="569"/>
      <source>Settings</source>
      <translation>Ajustes</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="570"/>
      <source>Orbit style</source>
      <translation>Estilo de órbita</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="571"/>
      <source>Compact</source>
      <translation>Compacto</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="572"/>
      <source>Tooltip</source>
      <translation>Información sobre herramientas</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="573"/>
      <source>Turntable</source>
      <translation>Mesa giratoria</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="574"/>
      <source>Free Turntable</source>
      <translation>Turntable libre</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="575"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="576"/>
      <source>Undefined</source>
      <translation>Indefinido</translation>
    </message>
  </context>
</TS>
